# VoiLib

VoiBot is a Python library for creating virtual assistants using OpenAI and Retrieval-Augmented Generation (via LangChain)

## Features
- Support for OpenAI's GPT models
- Retrieval-Augmented Generation (RAG)
- Custom intents and automatic replies
